/**
 * \file src/gui/xic_view/xic_box/xicbox.cpp
 * \date 12/1/2018
 * \author Olivier Langella
 * \brief XIC box widget
 */
/*******************************************************************************
* Copyright (c) 2018 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/

#include "xicbox.h"
#include "ui_xic_box.h"
#include <QMessageBox>
#include <pappsomspp/pappsoexception.h>
#include "../xicworkerthread.h"

XicBox::XicBox(XicWindow *parent):
    QWidget(parent),
    ui(new Ui::XicBox)
{
    _p_xic_window = parent;
    ui->setupUi(this);

    XicWorkerThread * p_worker = new XicWorkerThread();
    p_worker->moveToThread(&_xic_thread);
    _xic_thread.start();

#if QT_VERSION >= 0x050000
    // Qt5 code
    connect(this, &XicBox::loadXic, p_worker, &XicWorkerThread::doXicLoad);
    connect(p_worker, &XicWorkerThread::xicLoaded,this, &XicBox::setXic);
    connect(p_worker, &XicWorkerThread::operationFailed, this, &XicBox::error);

#else
// Qt4 code
#endif


}

XicBox::~XicBox()
{
    qDebug() << "XicBox::~XicBox";
    _xic_thread.quit();
    _xic_thread.wait();
}

void XicBox::error(QString error_message) {
    QMessageBox::warning(this,
                         tr("Error trying to save spectrum to SVG file :"), error_message);

}
void XicBox::setPeptideEvidence(const PeptideEvidence * p_peptide_evidence) {

    _p_peptide_evidence = p_peptide_evidence;
    ui->peptide_label->setText(_p_peptide_evidence->getPeptideXtpSp().get()->toString());

    emit loadXic(_p_peptide_evidence->getMsRunP(), _p_peptide_evidence->getPeptideXtpSp().get()->getMz(_p_peptide_evidence->getCharge()), _p_xic_window->getXicExtractPrecision(), XicExtractMethod::max);

}


void XicBox::setXic(pappso::XicSp xic_sp) {
    qDebug() << "XicBox::setXic begin";
    qDebug() << "XicBox::setXic end";
    
}
