/**
 * \file src/gui/xic_view/xic_box/xicbox.h
 * \date 12/1/2018
 * \author Olivier Langella
 * \brief XIC box widget
 */
/*******************************************************************************
* Copyright (c) 2018 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/

#ifndef XICBOX_H
#define XICBOX_H

#include <QWidget>
#include <QThread>
#include "../../../utils/types.h"
#include "../../../core/peptideevidence.h"
#include "../xicwindow.h"
#include <pappsomspp/xic/xic.h>

namespace Ui {
class XicBox;
}

class XicBox: public QWidget 
{
    Q_OBJECT
public:

    explicit XicBox(XicWindow * parent = 0);
    ~XicBox();
    void setPeptideEvidence(const PeptideEvidence * p_peptide_evidence) ;
    
signals :
    void loadXic(const MsRun * p_msrun, pappso::mz mz, pappso::PrecisionP precision, XicExtractMethod method);
private slots:
    void setXic(pappso::XicSp xic_sp);
    void error(QString error_message);
private:
    Ui::XicBox *ui;
    QThread _xic_thread;
    XicWindow * _p_xic_window;
    const PeptideEvidence * _p_peptide_evidence;
};


#endif // XICBOX_H
