/**
 * \file src/gui/xic_view/xicworkerthread.cpp
 * \date 12/1/2018
 * \author Olivier Langella
 * \brief XIC worker
 */
/*******************************************************************************
* Copyright (c) 2018 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/


#include "xicworkerthread.h"
#include "../../utils/readspectrum.h"
#include <pappsomspp/pappsoexception.h>

void XicWorkerThread::doXicLoad(const MsRun * p_msrun, pappso::mz mz, pappso::PrecisionP precision, XicExtractMethod method) {

    try {
        pappso::MassRange mass_range(mz, precision);
        pappso::XicSp xic_sp = SpectrumStore::getXicSpFromMsRunSp(p_msrun, mass_range, method);

        emit xicLoaded(xic_sp);

    }
    catch (pappso::PappsoException & error) {
        emit operationFailed(tr("Error extracting XIC :\n%1").arg(error.qwhat()));
    }
}
